/*
 * Copyright (C) 2012-2019 Japan Smartphone Security Association
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jssec.android.webview.safebrowsing;

import androidx.appcompat.app.AppCompatActivity;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.webkit.ValueCallback;
import android.webkit.WebView;

import java.util.ArrayList;
import java.util.Arrays;

public class MainActivity extends AppCompatActivity {

    private boolean mSafeBrowsingIsInitialized;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        findViewById(R.id.button1).setOnClickListener(setWhiteList);
        findViewById(R.id.button2).setOnClickListener(reload);

        final WebView webView = findViewById(R.id.webView);
        webView.setWebViewClient(new MyWebViewClient());

        mSafeBrowsingIsInitialized = false;
        // Android 8.1 未満の端末ではサポートされないため、実際の実装時には端末のAndroid OSバージョンで処理を分ける必要がある
        WebView.startSafeBrowsing(this, new ValueCallback<Boolean>() {
                @Override
                public void onReceiveValue(Boolean result) {
                    mSafeBrowsingIsInitialized = true;
                    if (result) {
                        Log.i("WebView SafeBrowsing", "Initialized SafeBrowsing!");
                        webView.loadUrl("http://testsafebrowsing.appspot.com/s/malware.html");
                    } else {
                        Log.w("WebView SafeBrowsing", "SafeBrowsing initialization failed...");
                        // 初期化処理が失敗したため、Safe Browsingがうまく動作しない可能性がある
                        // この場合URLをロードしないことが望ましい
                    }
                }
            });
    }

    View.OnClickListener setWhiteList = new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                // Safe Browsing機能を適用させないHost名・IPアドレスのホワイトリストを設定する
                WebView.setSafeBrowsingWhitelist(new ArrayList<>(Arrays.asList("testsafebrowsing.appspot.com")),
                                                 new ValueCallback<Boolean>() {
                        @Override
                        public void onReceiveValue(Boolean aBoolean) {
                            Log.i("WebView SafeBrowsing", "Whitelisted " + aBoolean.toString());
                        }
                    });
            }
        };

    View.OnClickListener reload = new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                final WebView webView = findViewById(R.id.webView);
                webView.reload();
            }
        };
}
